/*********************************************************************
  All ADuC7023 library code provided by ADI, including this file, is provided
 as is without warranty of any kind, either expressed or implied.
 You assume any and all risk from the use of this code.  It is the
 responsibility of the person integrating this code into an application
 to ensure that the resulting application performs as required and is safe.

 Author        : ADI - Apps            www.analog.com/ADuC7023

 Date          : February 2009

 File          : Flash_Erase.c

 Hardware      : ADuC706x

 Description   : The program shows how to erase/protect the entire internal Flash memory block
*************************************************************************************************/
// Bit Definitions
#define BIT0  0x01
#define BIT1  0x02
#define BIT2  0x04
#define BIT3  0x08
#define BIT4  0x10
#define BIT5  0x20
#define BIT6  0x40
#define BIT7  0x80
#define BIT8  0x100
#define BIT9  0x200
#define BIT10 0x400
#define BIT11 0x800
#define BIT12 0x1000
#define BIT13 0x2000
#define BIT14 0x4000
#define BIT15 0x8000
#define BIT16 0x10000
#define BIT21 0x200000
#define BIT22 0x400000
#define BIT23 0x800000
#define BIT24 0x1000000
#define BIT26 0x4000000
#define BIT30 0x40000000
#define BIT31 0x80000000
unsigned char ucToggleRate = 0;
unsigned int uiTest = 0;

#include<aduc7023.h>

int main(void)
{
	POWKEY1 = 0x01;					// Configure CPU Clock for 41.78MHz, CD=0
 	POWCON = 0x00;
 	POWKEY2 = 0xF4;

	GP0DAT  = BIT31;				// Configure P0.7 as an output

	// Initilize Timer 1 in Periodic mode with timeout period of 1 Second
	T1LD  = 0x4000;					// T1LD x 32768 clock ticks
	T1CON = BIT3 + BIT6 + BIT7;		// Periodic mode, enable timer, 32768hz clock/256
	IRQCONE = BIT1;					// Rising edge
	IRQEN = BIT3 + BIT13			// Enable Timer 1 IRQ + XIRQ0
			+ BIT16;				// Enable External IRQ1
	while(1)
	{

	}
}

void IRQ_Handler(void) __irq  
{
   unsigned long IRQSTATUS = 0;
  
    IRQSTATUS = IRQSTA;	   			// Read off IRQSTA register
	if ((IRQSTATUS & BIT3) == BIT3)	//Timer 1 interrupt source
	{
		 GP0DAT ^= BIT23;			// Toggle (P0.7)
		 T1CLRI = 0x55;				// Clear the currently active Timer0 Irq

	}
	if ((IRQSTATUS & BIT13) == BIT13)//External Interrupt0 source
	{
		FEEMOD |= 0x8;				//Erase key enable
	 	FEEADR = 0xFFC3;
		FEEDAT = 0x3CFF;	
		FEECON = 0x06;				//Mass erase command
	   	IRQCLR = BIT13;
	}
	if ((IRQSTATUS & BIT16) == BIT16)//XIRQ1 interrupt source
	{	
		IRQCLR = BIT16;
		FEEMOD |= 0x48;				// Set bits 6 and 3 of FEEMOD.
		FEEMOD &= ~0x20;			// Clear bit 5 of FEEMOD
		FEEADR = 0x1234;
		FEEDAT = 0x5678;	
		FEEPRO = 0x80000000;		// Write Protect all pages but allow JTAG Read access
	//	FEEPRO = 0x00000000;		// Protect all pages and not allow JTAG Read access
		FEECON = 0x0C;				// Flash Protection command
	}

}


